#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <previous ups version> <new ups version>"
   echo "Please run from the top level directory of the repository"
}


# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

prev_ups_version=${1}
ups_version=${2}

if [ -z ${ups_version} ] || [ -z ${prev_ups_version} ]
then 
    usage
    echo "Provided previous version: $prev_ups_version"
    echo "Provided new      version: $ups_version"
    exit 1
fi

# -------------------------------------------------------------------
# need to edit the table/NULL/ups/novaenv.table and version/NULL_ files
# to have the correct version numbers
# also need to tag the repository
# -------------------------------------------------------------------

sed -i~ 's/'${prev_ups_version}'/'${ups_version}'/' table/NULL/ups/novaddtdeps.table
sed -i~ 's/'${prev_ups_version}'/'${ups_version}'/' version/NULL_

# now commit these changes to the repository
svn commit -m"preparing for ups version tag $ups_version"

# copy the trunk to the tag
svn cp svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/trunk \
svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/tags/${ups_version} \
-m'create tag for ups version ${ups_version}'

# rename the directories in the tag to be the new version numbers
svn mv svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/tags/${ups_version}/table \
svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/tags/${ups_version}/${ups_version} \
-m'rename directory to correspond to new version number'

svn mv svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/tags/${ups_version}/version \
svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt-novaddtdeps/tags/${ups_version}/${ups_version}.version \
-m'rename directory to correspond to new version number'

exit 0

